@@ -3,7 +3,7 @@ Utilities.
 """
 
 from pscript import this_is_js
-from pscript.stubs import window, perf_counter, RawJS, Math
+from pscript.stubs import window, perf_counter, localStorage, RawJS, Math, JSON
 
 
 def looks_like_desktop():
@@ -511,6 +511,41 @@ class Picker:
                 return ob
 
 
+class LocalSettings:
+    """ Settings stored in localstorage. Also easier API than the stores. """
+
+    def __init__(self):
+        self._cache = self._load_settings()
+
+    def _load_settings(self):
+        x = localStorage.getItem("timetagger_local_settings")
+        if x:
+            try:
+                return JSON.parse(x)
+            except Exception as err:
+                window.console.warn("Cannot parse local settings JSON: " + str(err))
+                return {}
+        else:
+            return {}
+
+    def _save_settings(self):
+        x = JSON.stringify(self._cache)
+        localStorage.setItem("timetagger_local_settings", x)
+
+    def get(self, key, default_=None):
+        """ Get a settings item. """
+        return self._cache.get(key, default_)
+
+    def set(self, key, value):
+        """ Save a setting. """
+        self._cache[key] = value
+        self._save_settings()
+
+
+if this_is_js():
+    window.localsettings = LocalSettings()
+
+
 class BaseCanvas:
     """A Canvas wrapper that automatically resizes and takes high-res into account."""
 
